Multiple-precision Reals
========================

.. currentmodule:: gmpy2

mpfr Type
---------

.. autoclass:: mpfr
   :special-members: __format__

mpfr Functions
--------------

.. autofunction:: agm
.. autofunction:: ai
.. autofunction:: atan2
.. autofunction:: cbrt
.. autofunction:: ceil
.. autofunction:: check_range
.. autofunction:: cmp
.. autofunction:: const_catalan
.. autofunction:: const_euler
.. autofunction:: const_log2
.. autofunction:: const_pi
.. autofunction:: cot
.. autofunction:: coth
.. autofunction:: csc
.. autofunction:: csch
.. autofunction:: degrees
.. autofunction:: digamma
.. autofunction:: eint
.. autofunction:: erf
.. autofunction:: erfc
.. autofunction:: exp10
.. autofunction:: exp2
.. autofunction:: expm1
.. autofunction:: factorial
.. autofunction:: floor
.. autofunction:: fmma
.. autofunction:: fmms
.. autofunction:: fmod
.. autofunction:: frac
.. autofunction:: frexp
.. autofunction:: fsum
.. autofunction:: gamma
.. autofunction:: gamma_inc
.. autofunction:: get_exp
.. autofunction:: hypot
.. autofunction:: inf
.. autofunction:: is_finite
.. autofunction:: is_infinite
.. autofunction:: is_regular
.. autofunction:: is_signed
.. autofunction:: is_unordered
.. autofunction:: j0
.. autofunction:: j1
.. autofunction:: jn
.. autofunction:: lgamma
.. autofunction:: li2
.. autofunction:: lngamma
.. autofunction:: log1p
.. autofunction:: log2
.. autofunction:: maxnum
.. autofunction:: minnum
.. autofunction:: modf
.. autofunction:: mpfr_from_old_binary
.. autofunction:: mpfr_grandom
.. autofunction:: mpfr_nrandom
.. autofunction:: mpfr_random
.. autofunction:: nan
.. autofunction:: next_above
.. autofunction:: next_below
.. autofunction:: radians
.. autofunction:: rec_sqrt
.. autofunction:: reldiff
.. autofunction:: remainder
.. autofunction:: remquo
.. autofunction:: rint
.. autofunction:: rint_ceil
.. autofunction:: rint_floor
.. autofunction:: rint_round
.. autofunction:: rint_trunc
.. autofunction:: root
.. autofunction:: rootn
.. autofunction:: round2
.. autofunction:: round_away
.. autofunction:: sec
.. autofunction:: sech
.. autofunction:: set_exp
.. autofunction:: set_sign
.. autofunction:: sign
.. autofunction:: sinh_cosh
.. autofunction:: trunc
.. autofunction:: y0
.. autofunction:: y1
.. autofunction:: yn
.. autofunction:: zero
.. autofunction:: zeta
.. autofunction:: get_max_precision
.. autofunction:: get_emax_max
.. autofunction:: get_emin_min
.. autofunction:: copy_sign
.. autofunction:: can_round
.. autofunction:: free_cache
